<!DOCTYPE html>
{% load i18n static admin_black %}
{% get_current_language as LANGUAGE_CODE %}
{% get_current_language_bidi as LANGUAGE_BIDI %}
{% get_direction as direction %}
{% get_admin_setting as admin_setting %}
<html lang="en">

<head>
    {% include 'includes/head.html' %}
    {% block extrahead %}{% endblock extrahead %}
    {% block extrastyle %}{% endblock extrastyle %}
</head>

<body class="{% block bodyclass %}{% endblock bodyclass %}">
    <div class="wrapper">
        {% block sidebar %}
        {% include 'includes/sidebar.html' %}
        {% endblock sidebar %}
        <div class="main-panel">
            {% block navigation %}
            {% include 'includes/navigation.html' %}
            {% endblock navigation %}
            {% block content %}{% endblock content %}
            {% block footer %}
            {% include 'includes/footer.html' %}
            {% endblock footer %}
        </div>
    </div>
    {% block fixed-plugin %}
    {% include 'includes/fixed-plugin.html' %}
    {% endblock fixed-plugin %}
    {% include 'includes/scripts.html' %}
    {% block extrajs %}{% endblock extrajs %}
</body>

</html>