{% extends 'layouts/base.html' %}
{% load static %}
{% block content %}
<div class="content">
  <div class="row">
    <div class="col-md-12">
      <div class="card card-plain">
        <div class="card-header">
          Google Maps
        </div>
        <div class="card-body">
          <div id="map" class="map"></div>
        </div>
      </div>
    </div>
  </div>
</div>
{% endblock content %}
{% block extrajs %}
<script>
  $(document).ready(function () {
    // Javascript method's body can be found in assets/js/demos.js
    demo.initGoogleMaps();
  });
</script>{% endblock extrajs %}