{% load static %}
<!--   Core JS Files   -->
<script src="{% static 'assets/js/core/jquery.min.js' %}"></script>
<script src="{% static 'assets/js/core/popper.min.js' %}"></script>
<script src="{% static 'assets/js/core/bootstrap.min.js' %}"></script>
<script src="{% static 'assets/js/plugins/perfect-scrollbar.jquery.min.js' %}"></script>
<!--  Google Maps Plugin    -->
<!-- Place this tag in your head or just before your close body tag. -->
<script src="https://maps.googleapis.com/maps/api/js?key=YOUR_KEY_HERE"></script>
<!-- Chart JS -->
<script src="{% static 'assets/js/plugins/chartjs.min.js' %}"></script>
<!--  Notifications Plugin    -->
<script src="{% static 'assets/js/plugins/bootstrap-notify.js' %}"></script>
<!-- Control Center for Black Dashboard: parallax effects, scripts for the example pages etc -->
<script src="{% static 'assets/js/black-dashboard.min.js' %}?v=1.0.0"></script>
<!-- Black Dashboard DEMO methods, don't include it in your project! -->
<script src="{% static 'assets/demo/demo.js' %}"></script>
<script src="{% static 'assets/js/themeSettings.js' %}"></script>

<script>
    $(document).ready(function () {
        // Javascript method's body can be found in assets/js/demos.js
        demo.initDashboardPageCharts();

    });
</script>
<script src="https://cdn.trackjs.com/agent/v3/latest/t.js"></script>
<script>
    window.TrackJS &&
        TrackJS.install({
            token: "ee6fab19c5a04ac1a32a645abde4613a",
            application: "black-dashboard-free"
        });
</script>