<footer class="footer">
    <div class="container-fluid">
        <ul class="nav">
            <li class="nav-item">
                <a href="https://appseed.us/product/black-dashboard/django/" target="_blank" class="nav-link">
                    Download
                </a>
            </li>
            <li class="nav-item">
                <a href="https://appseed.us/product/black-dashboard-pro/django/" target="_blank" class="nav-link">
                    PRO Version
                </a>
            </li>
            <li class="nav-item">
                <a href="https://appseed.us/support/" target="_blank" class="nav-link">
                    Support
                </a>
            </li>
        </ul>
        <div class="copyright">
            &copy; 
            <a href="https://bit.ly/3fKQZaL" target="_blank">Creative Tim</a> - Coded by AppSeed.
        </div>
    </div>
</footer>