{% load i18n %}

<div class="filter_panel">
    <div class="mb-3">
        <span class="h6">{% blocktrans with filter_title=title %} By {{ filter_title }} {% endblocktrans %}</span>
    </div>
    <ul>
        {% for choice in choices %}
            <li{% if choice.selected %} class="text-success selected"{% endif %}>
                <a href="{{ choice.query_string|iriencode }}" title="{{ choice.display }}">{{ choice.display }}</a>
            </li>
        {% endfor %}
    </ul>
</div>
