@mixin alert-variant($background, $border, $color) {
    color: color-yiq($background);
    // @include gradient-bg($background);
    background-color: lighten($background, 5%);
    border-color: $border;

    hr {
        border-top-color: darken($border, 5%);
    }

    .alert-link {
        color: darken($color, 10%);
    }
}
