{% load static %}
<meta charset="utf-8" />
<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
<link rel="apple-touch-icon" sizes="76x76" href="{% static 'assets/img/apple-icon.png' %}">
<link rel="icon" type="image/png" href="{% static 'assets/img/favicon.png' %}">
<title>
    Black Dashboard by Creative Tim
</title>
<!--     Fonts and icons     -->
<link href="https://fonts.googleapis.com/css?family=Poppins:200,300,400,600,700,800" rel="stylesheet" />
<link href="https://use.fontawesome.com/releases/v5.0.6/css/all.css" rel="stylesheet">
<!-- Nucleo Icons -->
<link href="{% static 'assets/css/nucleo-icons.css' %}" rel="stylesheet" />
<!-- CSS Files -->
<link href="{% static 'assets/css/black-dashboard.css' %}?v=1.0.0" rel="stylesheet" />
<link href="{% static 'assets/css/theme-switcher.css' %}" rel="stylesheet" />
<!-- CSS Just for demo purpose, don't include it in your project -->
<link href="{% static 'assets/demo/demo.css' %}" rel="stylesheet" />