# Generated by Django 3.1.1 on 2020-11-02 18:06

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='AdminBlackSetting',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sidebar_background', models.CharField(default='primary', max_length=20, verbose_name='sidebar background')),
                ('dark_mode', models.BooleanField(default=True, verbose_name='dark mode')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='created at')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='updated at')),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, related_name='admin_black_setting', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'dashboard setting',
                'verbose_name_plural': 'dashboard settings',
            },
        ),
    ]
