<div class="sidebar">
  <!--
      Tip 1: You can change the color of the sidebar using: data-color="blue | green | orange | red"
  -->
  <div class="sidebar-wrapper">
    <div class="logo">
      <a href="javascript:void(0)" class="simple-text logo-mini">
        ط م
      </a>
      <a href="/" class="simple-text logo-normal">
        توقيت الإبداعية
      </a>
    </div>
    <ul class="nav">
      <li>
        <a href="/">
          <i class="tim-icons icon-chart-pie-36"></i>
          <p>لوحة القيادة</p>
        </a>
      </li>
      <li>
        <a href="{% url 'icons' %}">
          <i class="tim-icons icon-atom"></i>
          <p>الرموز</p>
        </a>
      </li>
      <li>
        <a href="{% url 'map' %}">
          <i class="tim-icons icon-pin"></i>
          <p>خرائط</p>
        </a>
      </li>
      <li>
        <a href="{% url 'notifications' %}">
          <i class="tim-icons icon-bell-55"></i>
          <p>إخطارات</p>
        </a>
      </li>
      <li>
        <a href="{% url 'user_profile' %}">
          <i class="tim-icons icon-single-02"></i>
          <p>ملف تعريفي للمستخدم</p>
        </a>
      </li>
      <li>
        <a href="{% url 'tables' %}">
          <i class="tim-icons icon-puzzle-10"></i>
          <p>قائمة الجدول</p>
        </a>
      </li>
      <li>
        <a href="{% url 'typography' %}">
          <i class="tim-icons icon-align-center"></i>
          <p>طباعة</p>
        </a>
      </li>
      <li>
        <a href="{% url 'rtl' %}">
          <i class="tim-icons icon-world"></i>
          <p>دعم RTL</p>
        </a>
      </li>
      <li>
        <a href="{% url 'upgrade' %}">
          <i class="tim-icons icon-spaceship"></i>
          <p>التطور للاحترافية</p>
        </a>
      </li>
    </ul>
  </div>
</div>